==> drupalmoduleupgrader-8.x-0.6.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/Routing.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drupalmoduleupgrader\Converter\Routing\Drupal7\RouteWrapper as Drupal7Route;
use Drupal\drupalmoduleupgrader\Converter\Routing\HookMenu;
use Drupal\drupalmoduleupgrader\ConverterBase;
use Drupal\drupalmoduleupgrader\TargetInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Converter(
 *  id = "routing",
 *  description = @Translation("Converts parts of hook_menu() to the Drupal 8 routing system."),
 *  hook = "menu"
 * )
 */
class Routing extends ConverterBase implements ContainerFactoryPluginInterface {

  /**
   * The route converters' plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $routeConverters;

  /**
   * Constructs a Routing object.
   *
   * @param array $configuration
   *   Additional configuration for the plugin.
   * @param string $plugin_id
   *   The plugin ID, will be "Links".
   * @param mixed $plugin_definition
   *   The plugin definition as derived from the annotations.
   *
   * @param PluginManagerInterface $route_converters
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PluginManagerInterface $route_converters) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeConverters = $route_converters;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.drupalmoduleupgrader.route')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function convert(TargetInterface $target) {
    $hook_menu = new HookMenu($target, $this->routeConverters);
    foreach ($hook_menu->getSourceRoutes() as $path => $route) {
      /** @var \Drupal\drupalmoduleupgrader\Converter\Routing\Drupal7\RouteWrapper $route */
      if ($route->containsKey('page callback')) {
        /** @var \Drupal\drupalmoduleupgrader\Converter\Routing\RouteConverterInterface $converter */
        $this->getRouteConverter($route)->buildRoute($target, $route);
      }
    }

    $routing = [];
    foreach ($hook_menu->getDestinationRoutes() as $name => $route) {
      $routing[$name] = [
        'path' => $route->getPath()->__toString(),
        'defaults' => $route->getDefaults(),
        'requirements' => $route->getRequirements(),
      ];
    }
    $this->writeInfo($target, 'routing', $routing);
  }

  /**
   * Gets the appropriate route converter for a Drupal 7 router item, if one exists.
   *
   * @param \Drupal\drupalmoduleupgrader\Converter\Routing\Drupal7\RouteWrapper $route
   *  The original Drupal 7 route.
   *
   * @return \Drupal\drupalmoduleupgrader\ConverterInterface
   */
  private function getRouteConverter(Drupal7Route $route) {
    $plugin_id = $route['page callback'];

    // Check if there is a route converter to handle this page callback.
    if (! $this->routeConverters->hasDefinition($plugin_id)) {
      $plugin_id = 'default';
    }

    return $this->routeConverters->createInstance($plugin_id);
  }

}

==> drupalmoduleupgrader-8.x-0.7.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/Routing.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drupalmoduleupgrader\Converter\Routing\HookMenu;
use Drupal\drupalmoduleupgrader\ConverterBase;
use Drupal\drupalmoduleupgrader\TargetInterface;
use Drupal\drupalmoduleupgrader\Utility\Filter\ContainsLogicFilter;
use Pharborist\DocCommentNode;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Converter(
 *  id = "routing",
 *  description = @Translation("Converts parts of hook_menu() to the Drupal 8 routing system."),
 *  hook = "menu",
 *  fixme = @Translation("@FIXME
This implementation of hook_menu() cannot be automatically converted because
it contains logic (i.e., branching statements, function calls, object
instantiation, etc.) You will need to convert it manually. Sorry!

For more information on how to convert hook_menu() to Drupal 8's new routing
and linking systems, see https://api.drupal.org/api/drupal/core%21includes%21menu.inc/group/menu/8")
 * )
 */
class Routing extends ConverterBase implements ContainerFactoryPluginInterface {

  /**
   * The route converters' plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $routeConverters;

  /**
   * Constructs a Routing object.
   *
   * @param array $configuration
   *   Additional configuration for the plugin.
   * @param string $plugin_id
   *   The plugin ID, will be "Links".
   * @param mixed $plugin_definition
   *   The plugin definition as derived from the annotations.
   *
   * @param PluginManagerInterface $route_converters
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, PluginManagerInterface $route_converters) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeConverters = $route_converters;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.drupalmoduleupgrader.route')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function convert(TargetInterface $target) {
    // If the hook implementation contains logic, we cannot convert it and
    // that's that. So we'll leave a FIXME and bail out.
    /** @var \Pharborist\Functions\FunctionDeclarationNode $hook */
    $hook = $target->getIndexer('hook')->get('menu')->get(0);
    if ($hook->is(new ContainsLogicFilter)) {
      $hook->setDocComment(DocCommentNode::create($this->pluginDefinition['fixme']));
      $target->getCodeManager()->save($hook);
      return;
    }

    $hook_menu = new HookMenu($target, $this->routeConverters);
    foreach ($hook_menu->getSourceRoutes() as $path => $route) {
      /** @var \Drupal\drupalmoduleupgrader\Converter\Routing\Drupal7\RouteWrapper $route */
      if ($route->containsKey('page callback')) {
        $plugin_id = $this->routeConverters->hasDefinition($route['page callback']) ? $route['page callback'] : 'default';
        /** @var \Drupal\drupalmoduleupgrader\Converter\Routing\RouteConverterInterface $converter */
        $this->routeConverters->createInstance($plugin_id)->buildRoute($target, $route);
      }
    }

    $routing = [];
    foreach ($hook_menu->getDestinationRoutes() as $name => $route) {
      $routing[$name] = [
        'path' => $route->getPath()->__toString(),
        'defaults' => $route->getDefaults(),
        'requirements' => $route->getRequirements(),
      ];
    }
    $this->writeInfo($target, 'routing', $routing);
  }

}
